/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.model.constraints.IConstraint;
import org.fortiss.tooling.kernel.ui.extension.IAllocationEditPartFactory;
import org.fortiss.tooling.kernel.ui.extension.IConstraintVerifierUI;
import org.fortiss.tooling.kernel.ui.extension.IContextMenuContributor;
import org.fortiss.tooling.kernel.ui.extension.IEditPartFactory;
import org.fortiss.tooling.kernel.ui.extension.IModelEditorBinding;
import org.fortiss.tooling.kernel.ui.extension.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.service.IActionService;
import org.fortiss.tooling.kernel.ui.service.IAllocationEditPartFactoryService;
import org.fortiss.tooling.kernel.ui.service.IConstraintVerificationUIService;
import org.fortiss.tooling.kernel.ui.service.IContextMenuService;
import org.fortiss.tooling.kernel.ui.service.IEditPartFactoryService;
import org.fortiss.tooling.kernel.ui.service.IMarkerService;
import org.fortiss.tooling.kernel.ui.service.IModelEditorBindingService;
import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;
import org.fortiss.tooling.kernel.ui.service.INavigatorService;
import org.fortiss.tooling.kernel.ui.service.ITutorialUIService;

/**
 * Implementations for initializing and starting the UI part of the tooling kernel.
 * 
 * @author hoelzl
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public final class ToolingKernelUIInternal {

	/** Initializes the UI services. */
	public static void initializeKernelUI() {
		System.out.println("Tooling Kernel UI initializing ...");
		((ActionService)IActionService.getInstance()).initializeService();
		((AllocationEditPartFactoryService)IAllocationEditPartFactoryService.getInstance())
				.initializeService();
		((ConstraintVerificationUIService)IConstraintVerificationUIService.getInstance())
				.initializeService();
		((ContextMenuService)IContextMenuService.getInstance()).initializeService();
		((EditPartFactoryService)IEditPartFactoryService.getInstance()).initializeService();
		((MarkerService)IMarkerService.getInstance()).initializeService();
		((ModelEditorBindingService)IModelEditorBindingService.getInstance()).initializeService();
		((ModelElementHandlerService)IModelElementHandlerService.getInstance()).initializeService();
		((NavigatorService)INavigatorService.getInstance()).initializeService();
		((TutorialUIService)ITutorialUIService.getInstance()).initializeService();
		System.out.println("Tooling Kernel UI initialized.");
	}

	/** Starts the UI services. */
	public static void startKernelUI() {
		System.out.println("Tooling Kernel UI starting ...");
		((ActionService)IActionService.getInstance()).startService();
		((AllocationEditPartFactoryService)IAllocationEditPartFactoryService.getInstance())
				.startService();
		((ConstraintVerificationUIService)IConstraintVerificationUIService.getInstance())
				.startService();
		((ContextMenuService)IContextMenuService.getInstance()).startService();
		((EditPartFactoryService)IEditPartFactoryService.getInstance()).startService();
		((MarkerService)IMarkerService.getInstance()).startService();
		((ModelEditorBindingService)IModelEditorBindingService.getInstance()).startService();
		((ModelElementHandlerService)IModelElementHandlerService.getInstance()).startService();
		((NavigatorService)INavigatorService.getInstance()).startService();
		((TutorialUIService)ITutorialUIService.getInstance()).startService();
		System.out.println("Tooling Kernel UI started.");
	}

	/** Registers the given allocation editpart factory with the kernel. */
	public static void registerAllocationEditpartFactory(IAllocationEditPartFactory factory,
			Class<EObject> modelElementClass) {
		((AllocationEditPartFactoryService)IAllocationEditPartFactoryService.getInstance())
				.registerAllocationEditpartFactory(factory, modelElementClass);
	}

	/** Registers the verifier UI part with the kernel. */
	public static <T extends IConstraint> void registerConstraintVerifierUI(
			IConstraintVerifierUI<T> verifier, Class<T> constraintElementClass) {
		((ConstraintVerificationUIService)IConstraintVerificationUIService.getInstance())
				.registerConstraintVerifierUI(verifier, constraintElementClass);
	}

	/** Registers the given contributor with the kernel. */
	public static void registerContextMenuContributor(IContextMenuContributor contributor) {
		((ContextMenuService)IContextMenuService.getInstance())
				.registerContextMenuContributor(contributor);
	}

	/** Registers the given editpart factory with the kernel. */
	public static void registerEditpartFactory(IEditPartFactory factory,
			Class<EObject> modelElementClass) {
		((EditPartFactoryService)IEditPartFactoryService.getInstance()).registerEditpartFactory(
				factory, modelElementClass);
	}

	/** Registers the given editor binding with the kernel. */
	public static <T extends EObject> void registerEditorBinding(IModelEditorBinding<T> binding,
			Class<T> modelElementClass) {
		((ModelEditorBindingService)IModelEditorBindingService.getInstance())
				.registerEditorBinding(binding, modelElementClass);
	}

	/** Registers the given handler with the kernel. */
	public static <T extends EObject> void registerModelElementHandler(
			IModelElementHandler<T> handler, Class<T> modelElementClass) {
		((ModelElementHandlerService)IModelElementHandlerService.getInstance())
				.registerModelElementHandler(handler, modelElementClass);
	}
}
